<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Kemmoù</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Kemer an AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Kemmoù</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klikit war an ikon barrenn-stad
pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>لا تدور شاشتك أثناء تسجيل الفيديو</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>التسجيل</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>إغلاق (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>نسخ إلى الحافظة (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Tapadenn skramm</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Chomet eo sac&apos;het an enrollañ. Enrollit e-barzh ur c&apos;havlec&apos;h personel eta.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Tapadenn-skramm echuet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>zonenn diuzañ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>اللصق</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>جارٍ حفظ ملف تسجيل الشاشة، يُرجى الانتظار...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>بما أن تأثير النافذة مُعطّل أثناء العملية، يجب أن تتوقف التسجيل</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>التدوير</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>الانقاص</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>فتح المجلد</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>تم إكمال التقاط الشاشة ولصقه</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>كل سؤال</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>موقع محدد</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>تحديد مسار عند الحفظ</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>تغيير المسار عند الحفظ</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Skeudennioù</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>الانقاص</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>التقاط شاشة</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>التقاط شاشة</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>التسجيل</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Gwelet</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Enrollañ echuet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Enrollet e-barzh %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>فتح المجلد</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>كل سؤال</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation></translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation></translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation></translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Skeudennioù</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>An dapadenn-skramm a loc&apos;ho a-benn %1 eilenn</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>احصل على مساعدة.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>فشل في التقاط شاشة متصلة.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>أصبحت في قاع منطقة التمرير</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>تم الوصول إلى الطول الأقصى</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>تعديل منطقة التقاط</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>تمرّر عجلة الفارة أو انقر لالتقاط شاشة تمريرية</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>تباطؤ سرعة التمرير</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>منطقة غير صالحة، انقر لـ</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skrivit ho testenn amañ</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Loc&apos;hañ/Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Kuitaat/Enrollañ</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Brasadur ar ment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arventennoù</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Loc&apos;hañ buan</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Tapadenn-skramm eus ar prenestr</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Dale an dapadenn-skramm</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tapadenn-skramm klok</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Skouergornek</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsenn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linenn</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kreion</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testenn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Dizober</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Brasaat an uhelder</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Brasaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Brasaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Brasaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Bihanaat an uhelder</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Bihanaat an uhelder war-draoñ</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Bihanaat al ledander a-gleiz</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Bihanaat al ledander a-zehoù</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>الزر</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Kregiñ da enrollañ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>البدء/التسجيل</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>الماوس</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>أدوات</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>استخراج النص</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>الشاشة المتدلية</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>إرفاق لقطات الشاشة</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>بدء تحويل النص</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>بدء الشاشة المتدلية</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Bir</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>مستطيل
اضغط واحتفظ بـ Shift لرسم مربع</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>مستطيل بيضاوي
اضغط واحتفظ بـ Shift لرسم دائرة</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>فرشاة
اضغط واحتفظ بـ Shift لرسم خط مستقيم</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>تعديل قوة التمويه (استخدم العجلة لتعديلها)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>تعديل حجم الفرشاة (استخدم العجلة لتعديلها)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>تعديل حجم النص (استخدم العجلة لتعديلها)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>عرض سجل المفاتيح (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>إخفاء سجل المفاتيح (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>عرض سجل المفاتيح (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>تشغيل الكاميرا (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>إيقاف تشغيل الكاميرا (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tapadenn-skramm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Arventennoù</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>الإعدادات (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>صوت النظام</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Dibarzhioù</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>عرض المؤشر</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>عرض النقر</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Enrollañ e-barzh</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Burev</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>الخط (L)
اضغط واحمل Shift لرسم خط أفقي أو رأسي</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>السهم (X)
اضغط واحمل Shift لرسم سهم أفقي أو رأسي</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>قلم (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>التشويه (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>النص (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>اللقطة التمريرية (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>استخراج النص (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>اللقطات الثابتة (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>الاستعادة (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Enrollañ</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>تغيير المسار عند الحفظ</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>تأثيرات الحدود</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>الظل</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>الحدود</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>استخراج النص</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>اضغط واحتفظ بـ Shift لرسم مربعات أو دوائر</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>حفظ إلى الموقع المحلي</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>حفظ إلى %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>موقع محدد</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation></translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation></translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>Tapadenn AI (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Enrollañ e-barzh ar burev</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Enrollañ e-barzh ar skeudenn</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>إغلاق (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>نسخ إلى الحافظة (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>موافق (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>تعديل منطقة التسجيل داخل %1*%2 للحصول على تأثير فيديو أفضل</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>التسجيل الشاشة غير مدعوم في الوقت الحالي</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
</context>
</TS>
